// Copyright Earl Warren <contact@earl-warren.org>
// Copyright Loïc Dachary <loic@dachary.org>
// SPDX-License-Identifier: MIT

package http

import (
	"net/http"
)

type NewMigrationHTTPClientFun func() *http.Client

type Interface interface {
	GetNewMigrationHTTPClient() NewMigrationHTTPClientFun
	SetNewMigrationHTTPClient(fun NewMigrationHTTPClientFun)
	GetSkipTLSVerify() bool
	SetSkipTLSVerify(skipTLSVerify bool)
	GetProxy() string
	SetProxy(proxy string)
}
